@@ -1,5 +1,11 @@
 from discord import DiscordException
 
+class ConnectionError(Exception):
+    pass
+
+class AsyncError(Exception):
+    pass
+
 class IPCError(DiscordException):
     """Base IPC exception class"""
     pass
